@@ -1,13 +1,15 @@
 test_that("regularization path correctly stops if max_variables reached", {
-
   x <- scale(heart$x)
   y <- heart$y
 
-  fit <- SLOPE(x, y,
-               family = "binomial",
-               max_variables = 10,
-               intercept = FALSE,
-               lambda = "bh")
+  fit <- SLOPE(
+    x,
+    y,
+    family = "binomial",
+    max_variables = 10,
+    intercept = FALSE,
+    lambda = "bh"
+  )
 
   path_length <- length(fit$alpha)
 
@@ -15,4 +17,3 @@ test_that("regularization path correctly stops if max_variables reached", {
 
   expect_lte(n_var, 10)
 })
-
