@@ -23,13 +23,11 @@ test_that("Prox and isotonic regression agree", {
   lambda <- sort(runif(n), decreasing = TRUE)
 
   out_isotone_ref <- prox_sorted_l1_isotone(x, lambda)
-  out_stack <- sortedL1Prox(x, lambda, "stack")
-  out_pava <- sortedL1Prox(x, lambda, "pava")
+  out_stack <- sortedL1Prox(x, lambda)
 
   tol <- .Machine$double.eps^0.95
 
   expect_equal(out_isotone_ref, out_stack)
-  expect_equal(out_isotone_ref, out_pava)
 })
 
 test_that("Prox works for simple examples", {
